Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-pages.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIgor Wiedler <iwiedler@gitlab.com>2020-04-30 11:47:52 +0300
committerIgor Wiedler <iwiedler@gitlab.com>2020-04-30 11:47:52 +0300
commit22cadaef88074326535e49fb0dc2d345619408da (patch)
tree2b5a621a22160fc25343d56e268ee00b86ffb893 /app_config.go
parent333138397f79ae4857abd775804359cbbf23aeac (diff)
rename GitlabServerURL to GitlabAPIServerURL (as per @@krasio)
Diffstat (limited to 'app_config.go')
-rw-r--r--app_config.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/app_config.go b/app_config.go
index 06679892..cbaed36f 100644
--- a/app_config.go
+++ b/app_config.go
@@ -41,8 +41,8 @@ type appConfig struct {
CustomHeaders []string
}
-// GitlabServerURL returns URL to a GitLab instance.
-func (config appConfig) GitlabServerURL() string {
+// GitlabAPIServerURL returns URL to a GitLab instance.
+func (config appConfig) GitlabAPIServerURL() string {
return config.GitLabAPIServer
}